What’s New in Bazaar 2.8? — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# What’s New in Bazaar 2.8?

Bazaar 2.8 is still under development, and will be released in Month Year. This document accumulates a high level summary of what’s changed. See the Breezy Release Notes for a full list.

<topics of interest here>

## Further information

For more detailed information on the changes made, see the the Breezy Release Notes for:

- the interim bzr milestones

- the plugins you use.

For a summary of changes made in earlier releases, see:

- What’s New in Bazaar 2.1?

- What’s New in Bazaar 2.2?

- What’s New in Bazaar 2.3?

- What’s New in Bazaar 2.4 (Oronsay)

- What’s New in Bazaar 2.5?

- What’s New in Bazaar 2.6?

- What’s New in Bazaar 2.7?